@@ -2,15 +2,10 @@
 #' 
 #' @import ggplot2
 #' @import leaflet
-#' @import rlang
-#' @import dplyr
 #' @import sf
-#' @import stars
-#' @import rgdal
-#' @importFrom janitor clean_names
-#' @importFrom stats quantile
-#' @importFrom leafpop popupTable
-#' @importFrom htmltools htmlEscape
+#' @importFrom rlang !!
+#' @importFrom rlang .data
+
 NULL
 
 #' Pipe operator
@@ -25,11 +20,6 @@ NULL
 #' @usage lhs \%>\% rhs
 NULL
 
-#' Nse force
-#'
-#' @importFrom rlang !!
-NULL
-
 #' Shiny input
 utils::globalVariables("input")
 
