@@ -1,17 +1,16 @@
 # leaflet sf functions
 
-#' @title Map of simple features in leaflet.
+#' @title Simple feature leaflet map.
 #' @description Map of simple features in leaflet that is not coloured. 
 #' @param data An sf object of geometry type point/multipoint, linestring/multilinestring or polygon/multipolygon geometry type. Required input.
 #' @param popup_vars_vctr Vector of quoted variable names to include in the popup. If NULL, defaults to making a leafpop::popupTable of all columns.
-#' @param pal Character vector of hex codes. Defaults to viridis. Use the pals package to find a suitable palette.
+#' @param pal Character vector of hex codes. 
 #' @param size_point Size of points (i.e. radius). Defaults to 2.
 #' @param size_line Size of lines around features (i.e. weight). Defaults to 2.
 #' @param alpha The opacity of the fill within features (i.e. fillOpacity). Defaults to 0.9. 
 #' @param basemap The underlying basemap. Either "light", "dark", "satellite", "street", or "ocean". Defaults to "light". Only applicable where shiny equals FALSE.
-#' @param title A title string that will be wrapped into the legend. Defaults to "Title"
+#' @param title A title string that will be wrapped into the legend. 
 #' @param col_labels_dp Select the appropriate number of decimal places for numeric variable auto legend labels. Defaults to 1.
-#' @param col_labels A vector of legend label values. Defaults to "[Feature]".
 #' @param map_id The shiny map id for a leaflet map within a shiny app. For standard single-map apps, id "map" should be used. For dual-map apps, "map1" and "map2" should be used. Defaults to "map".
 #' @return A leaflet object.
 #' @export
@@ -24,10 +23,10 @@ leaflet_sf <- function(data,
                        size_line = 2,
                        alpha = 0.9,
                        basemap = "light",
-                       title = "[Title]",
+                       title = NULL,
                        col_labels_dp = 1,
-                       col_labels = "[Feature]",
-                       map_id = "map") {
+                       map_id = "map")
+{
   
   data <- dplyr::ungroup(data)
   shiny <- shiny::isRunning()
@@ -57,13 +56,13 @@ leaflet_sf <- function(data,
   if(is.null(popup_vars_vctr)){
     popup_data <- data %>% 
       sf::st_drop_geometry() %>% 
-      sv_colnames_to_present()
+      rlang::set_names(~snakecase::to_sentence_case(.))
   }
   else {
     popup_data <- data %>% 
       dplyr::select(popup_vars_vctr) %>% 
       sf::st_drop_geometry() %>% 
-      sv_colnames_to_present()
+      rlang::set_names(~snakecase::to_sentence_case(.))
   }
   
   popup <- leafpop::popupTable(popup_data, row.numbers = FALSE, feature.id = FALSE)
@@ -104,7 +103,7 @@ leaflet_sf <- function(data,
       addLegend(
         layerId = col_id,
         colors = pal[1],
-        labels =  col_labels, 
+        labels =  "Feature", 
         title = stringr::str_replace_all(stringr::str_wrap(title, 20), "\n", "</br>"),
         position = "bottomright",
         opacity = 1,
@@ -145,7 +144,7 @@ leaflet_sf <- function(data,
       addLegend(
         layerId = col_id,
         colors = pal[1],
-        labels =  col_labels, 
+        labels =  "Feature", 
         title = stringr::str_replace_all(stringr::str_wrap(title, 20), "\n", "</br>"),
         position = "bottomright",
         opacity = 1,
@@ -185,7 +184,7 @@ leaflet_sf <- function(data,
       addLegend(
         layerId = col_id,
         colors = pal[1],
-        labels =  col_labels, 
+        labels =  "Feature", 
         title = stringr::str_replace_all(stringr::str_wrap(title, 20), "\n", "</br>"),
         position = "bottomright",
         opacity = 1,
@@ -193,43 +192,36 @@ leaflet_sf <- function(data,
       )
     
   }
-  
 }
 
-#' @title Map of simple features in leaflet that is coloured.
+#' @title Simple feature leaflet map that is coloured.
 #' @description Map of simple features in leaflet that is coloured. 
 #' @param data An sf object of geometry type point/multipoint, linestring/multilinestring or polygon/multipolygon geometry type. Required input.
 #' @param col_var Unquoted variable to colour the features by. Required input.
 #' @param text_var Unquoted variable to label the features by. If NULL, defaults to using the colour variable.
 #' @param popup_vars_vctr Vector of quoted variable names to include in the popup. If NULL, defaults to making a leafpop::popupTable of all columns.
-#' @param pal Character vector of hex codes. Defaults to viridis. Use the pals package to find a suitable palette.
+#' @param pal Character vector of hex codes. 
 #' @param pal_rev Reverses the palette. Defaults to FALSE.
 #' @param size_point Size of points (i.e. radius). Defaults to 2.
 #' @param size_line Size of lines around features (i.e. weight). Defaults to 2.
 #' @param alpha The opacity of the fill within features (i.e. fillOpacity). Defaults to 0.1. 
 #' @param basemap The underlying basemap. Either "light", "dark", "satellite", "street", or "ocean". Defaults to "light". Only applicable where shiny equals FALSE.
-#' @param title A title string that will be wrapped into the legend. Defaults to "Title".
+#' @param title A title string that will be wrapped into the legend. 
 #' @param col_cuts A vector of cuts to colour a numeric variable. If "bin" is selected, the first number in the vector should be either -Inf or 0, and the final number Inf. If "quantile" is selected, the first number in the vector should be 0 and the final number should be 1. Defaults to quartiles. 
-#' @param col_labels_dp Select the appropriate number of decimal places for numeric variable auto legend labels. Defaults to 1.
-#' @param col_labels Adjust the  x scale labels through a vector.
+#' @param col_labels_dp For numeric colour variables, the number of decimal places. Defaults to 1 for "quantile" col_method, and the lowest dp within the col_cuts vector for "bin".
 #' @param col_method The method of colouring features, either "bin", "quantile" or "category." if categorical colour variable, NULL results in "category". If numeric variable, defaults to "quantile". Note all numeric variables are cut to be inclusive of the min in the range, and exclusive of the max in the range (except for the final bucket which includes the highest value).
-#' @param col_na TRUE or FALSE  of whether to include NAs of the colour variable. Defaults to TRUE.
+#' @param col_na TRUE or FALSE of whether to include col_var NA values. Defaults to TRUE.
 #' @param map_id The shiny map id for a leaflet map within a shiny app. For standard single-map apps, id "map" should be used. For dual-map apps, "map1" and "map2" should be used. Defaults to "map".
 #' @return A leaflet object.
 #' @export
 #' @examples
 #' leaflet_sf_col(example_sf_polygon, density,
-#'      col_method = "quantile", col_cuts = c(0, 0.25, 0.5, 0.75, 0.95, 1),
-#'      title = "Modelled density, 2017")
+#'      col_method = "quantile", col_cuts = c(0, 0.25, 0.5, 0.75, 0.95, 1))
 #'
 #' leaflet_sf_col(example_sf_polygon, density,
-#'      col_method = "bin", col_cuts = c(0, 10, 50, 100, 150, 200, Inf),  col_labels_dp = 0,
-#'      title = "Modelled density, 2017")
+#'      col_method = "bin", col_cuts = c(0, 10, 50, 100, 150, 200, Inf))
 #'
-#' pal <- c("#4575B4", "#D3D3D3", "#D73027")
-#'
-#' leaflet_sf_col(example_sf_point, trend_category, pal = pal, col_method = "category",
-#'    title = "Monitored trends, 2008\u201317")
+#' leaflet_sf_col(example_sf_point, trend_category, pal = c("#4575B4", "#D3D3D3", "#D73027"))
 leaflet_sf_col <- function(data,
                            col_var,
                            text_var = NULL,
@@ -240,13 +232,13 @@ leaflet_sf_col <- function(data,
                            size_line = 2,
                            alpha = 0.9,
                            basemap = "light",
-                           title = "[Title]",
+                           title = NULL,
                            col_cuts = NULL,
-                           col_labels_dp = 1,
-                           col_labels = NULL,
+                           col_labels_dp = NULL,
                            col_method = NULL,
                            col_na = TRUE,
-                           map_id = "map") {
+                           map_id = "map"
+) {
   
   data <- dplyr::ungroup(data)
   shiny <- shiny::isRunning()
@@ -260,23 +252,31 @@ leaflet_sf_col <- function(data,
   text_var <- rlang::enquo(text_var)
   if(is.null(rlang::get_expr(text_var))) text_var <- col_var
   
-  if (col_na == FALSE) data <- data %>% 
-    dplyr::filter(!is.na(!!col_var))
+  if (col_na == FALSE) {
+    data <- data %>% 
+      dplyr::filter(!is.na(!!col_var))
+  }
   
   col_var_vctr <- dplyr::pull(data, !!col_var)
   text_var_vctr <- dplyr::pull(data, !!text_var)
   
-  if (is.null(col_method) & !is.numeric(col_var_vctr)) col_method <- "category"
-  if (is.null(col_method) & is.numeric(col_var_vctr)) col_method <- "quantile"
+  if(is.logical(col_var_vctr)) {
+    data <- data %>% 
+      dplyr::mutate(dplyr::across(!!col_var, ~factor(., levels = c("TRUE", "FALSE"))))
+    
+    col_var_vctr <- dplyr::pull(data, !!col_var)
+  }
+  
+  if (is.null(col_method)) {
+    if (!is.numeric(col_var_vctr)) col_method <- "category"
+    else if (is.numeric(col_var_vctr)) col_method <- "quantile"
+  }
   
   if (col_method == "category") {
-    if (is.null( col_labels)){ 
-      if (is.factor(col_var_vctr)) labels <- levels(col_var_vctr)
-      else if (is.character(col_var_vctr)) labels <- sort(unique(col_var_vctr))
-    }
-    else if (!is.null( col_labels)) labels <-  col_labels
+    if (is.factor(col_var_vctr)) col_labels <- levels(col_var_vctr)
+    else if (is.character(col_var_vctr)) col_labels <- sort(unique(col_var_vctr))
     
-    n_col <- length(labels)
+    n_col <- length(col_labels)
     
     if (is.null(pal)) pal <- sv_pal(n_col)
     else if (!is.null(pal)) pal <- pal[1:n_col]
@@ -308,8 +308,9 @@ leaflet_sf_col <- function(data,
       right = FALSE,
       na.color = "#A8A8A8"
     )
-    if (is.null( col_labels)) labels <-  sv_labels_from_cuts(col_cuts,  col_labels_dp)
-    else if (!is.null( col_labels)) labels <-  col_labels
+    
+    if(is.null(col_labels_dp)) col_labels_dp <- sv_max_dp(col_cuts)
+    col_labels <-  sv_numeric_bin_labels(col_cuts, col_labels_dp)
   }
   else if (col_method == "quantile") {
     if(is.null(col_cuts)) col_cuts <- seq(0, 1, 0.25)
@@ -333,8 +334,8 @@ leaflet_sf_col <- function(data,
       na.color = "#A8A8A8"
     )
     
-    if (is.null( col_labels)) labels <-  sv_labels_from_cuts(col_cuts,  col_labels_dp)
-    else if (!is.null( col_labels)) labels <-  col_labels
+    if(is.null(col_labels_dp)) col_labels_dp <- 1
+    col_labels <-  sv_numeric_bin_labels(col_cuts, col_labels_dp)
   }
   
   geometry_type <- unique(sf::st_geometry_type(data))
@@ -354,13 +355,13 @@ leaflet_sf_col <- function(data,
   if(is.null(popup_vars_vctr)){
     popup_data <- data %>% 
       sf::st_drop_geometry() %>% 
-      sv_colnames_to_present()
+      rlang::set_names(~snakecase::to_sentence_case(.))
   }
   else {
     popup_data <- data %>% 
       dplyr::select(popup_vars_vctr) %>% 
       sf::st_drop_geometry() %>% 
-      sv_colnames_to_present()
+      rlang::set_names(~snakecase::to_sentence_case(.))
   }
   
   popup <- leafpop::popupTable(popup_data, row.numbers = FALSE, feature.id = FALSE)
@@ -401,7 +402,7 @@ leaflet_sf_col <- function(data,
       addLegend(
         layerId = col_id,
         colors = pal,
-        labels = labels,
+        labels = col_labels,
         title = stringr::str_replace_all(stringr::str_wrap(title, 20), "\n", "</br>"),
         position = "bottomright",
         opacity = 1,
@@ -443,7 +444,7 @@ leaflet_sf_col <- function(data,
       addLegend(
         layerId = col_id,
         colors = pal,
-        labels = labels,
+        labels = col_labels,
         title = stringr::str_replace_all(stringr::str_wrap(title, 20), "\n", "</br>"),
         position = "bottomright",
         opacity = 1,
@@ -484,7 +485,7 @@ leaflet_sf_col <- function(data,
       addLegend(
         layerId = col_id,
         colors = pal,
-        labels = labels,
+        labels = col_labels,
         title = stringr::str_replace_all(stringr::str_wrap(title, 20), "\n", "</br>"),
         position = "bottomright",
         opacity = 1,
