@@ -6,10 +6,7 @@
 library(dplyr)
 library(simplevis)
 
-# data_folder <- "inst/shiny/template1/data/"
-# 
-# data <-  readRDS(paste0(data_folder, "data.RDS"))
-
+# read data from app data folder
 data <- ggplot2::diamonds %>%
   slice_sample(prop = 0.1)
 
@@ -17,28 +14,28 @@ color_vector <- sort(unique(data$color))
 
 selected_color <- "E"
 
-plot_data <- data %>%
+plot_data <- data1 %>%
   filter(color == selected_color) %>% 
   mutate(cut = stringr::str_to_sentence(cut)) %>%
   group_by(cut, clarity, .drop = FALSE) %>%
   summarise(average_price = round(mean(price), 0)) %>%
   mutate(average_price_thousands = round(average_price / 1000, 1)) %>%
   mutate(average_price = paste0("US$", prettyNum(average_price,  big.mark = ","))) %>% 
-  add_tip(c("cut", "clarity", "average_price"))
+  mutate_text(c("cut", "clarity", "average_price"))
 
 title <- paste0("Average diamond price of colour ", selected_color, " by cut and clarity")
 x_title <- "Average price ($US thousands)"
 y_title <- "Cut"
 
-plot <- ggplot_hbar_col(data = plot_data, 
-                        x_var = average_price_thousands, 
-                        y_var = cut, 
-                        col_var = clarity, 
-                        tip_var = tip_text,
-                        legend_ncol = 4,
-                        title = title, 
-                        x_title = x_title, 
-                        y_title = y_title)
+plot <- gg_hbar_col(plot_data, average_price_thousands, cut, clarity, 
+                    text_var = text,
+                    title = title, 
+                    x_title = x_title, 
+                    y_title = y_title,
+                    font_family = "Helvetica", 
+                    mobile = F)
+
+plot
 
 plotly::ggplotly(plot, tooltip = "text") %>% 
   plotly_camera()
